@@ -27,15 +27,15 @@ sub stepout : Test(4) {
 		skip( "perl5db $] dose not support c [line|sub]", 1 ) if $] =~ m/5.01500(3|4|5)/;
 		SKIP: {
 			skip( "perl5db v$self->{perl5db_ver} dose not support list context", 1 ) if $self->{perl5db_ver} == 1.35;
-			cmp_deeply( \@out, [ 'main::', 't/eg/02-sub.pl', 9, 'my $z = $x + $y;', 242 ], 'step_out to line 9' );
+			cmp_deeply( \@out, [ 'main::', 't/eg/02-sub.pl', 9, 'my $z = $x + $y;' ], 'stepover line 9' );
 		}
 	}
 	$self->{debugger}->get_lineinfo;
 	SKIP: {
 		skip( "perl5db $] dose not support c [line|sub]", 1 ) if $] =~ m/5.01500(3|4|5)/;
-		ok( $self->{debugger}->row == 9, 'row = 9' );
+		ok( $self->{debugger}->get_row == 9, 'row = 9' );
 	}
-	ok( $self->{debugger}->filename =~ m/02-sub/, 'filename = 02-sub.pl' );
+	ok( $self->{debugger}->get_filename =~ m/02-sub/, 'filename = 02-sub.pl' );
 	
 	$out = $self->{debugger}->step_out;
 	like( $out, qr/^Warning:.*list/s, 'Warning: failed to make list call' );
